@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2024 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration;
 
 import static org.junit.jupiter.api.Assertions.*;
@@ -22,6 +22,9 @@ public class BatchTest extends Common {
         "CREATE TABLE BatchTest (t1 int not null primary key auto_increment, t2 LONGTEXT)");
     createSequenceTables();
     stmt.execute("CREATE TABLE timestampCal(id int, val TIMESTAMP)");
+    stmt.execute(
+        "CREATE TABLE batchParamTest (sn_key INTEGER, sn_name VARCHAR(255), sn_description"
+            + " VARCHAR(255), sn_object LONGBLOB, CONSTRAINT pk_test_i PRIMARY KEY (sn_key) ) ");
   }
 
   @AfterAll
@@ -29,6 +32,7 @@ public class BatchTest extends Common {
     Statement stmt = sharedConn.createStatement();
     stmt.execute("DROP TABLE IF EXISTS timestampCal");
     stmt.execute("DROP TABLE IF EXISTS BatchTest");
+    stmt.execute("DROP TABLE IF EXISTS batchParamTest");
   }
 
   @Test
@@ -249,6 +253,7 @@ public class BatchTest extends Common {
 
   @Test
   public void differentParameterType() throws SQLException {
+    boolean expectUnknown = isMariaDBServer() && !isXpand() && !minVersion(11, 5, 0);
     try (Connection con = createCon("&useServerPrepStmts=false&useBulkStmtsForInserts=false")) {
       differentParameterType(con, false);
     }
@@ -257,12 +262,12 @@ public class BatchTest extends Common {
     }
     try (Connection con =
         createCon("&useServerPrepStmts=false&useBulkStmts&useBulkStmtsForInserts")) {
-      differentParameterType(con, isMariaDBServer() && !isXpand());
+      differentParameterType(con, expectUnknown);
     }
     try (Connection con =
         createCon(
             "&useServerPrepStmts=false&useBulkStmtsForInserts&useBulkStmts&disablePipeline")) {
-      differentParameterType(con, isMariaDBServer() && !isXpand());
+      differentParameterType(con, expectUnknown);
     }
     try (Connection con = createCon("&useServerPrepStmts&useBulkStmtsForInserts=false")) {
       differentParameterType(con, false);
@@ -277,10 +282,10 @@ public class BatchTest extends Common {
     try (Connection con =
         createCon(
             "&useServerPrepStmts&useBulkStmts&useBulkStmtsForInserts&allowLocalInfile=false")) {
-      differentParameterType(con, isMariaDBServer() && !isXpand());
+      differentParameterType(con, expectUnknown);
     }
     try (Connection con = createCon("&useServerPrepStmts=false&useBulkStmts&allowLocalInfile")) {
-      differentParameterType(con, isMariaDBServer() && !isXpand());
+      differentParameterType(con, expectUnknown);
     }
     try (Connection con = createCon("&useServerPrepStmts=false&allowLocalInfile")) {
       differentParameterType(con, false);
@@ -292,12 +297,12 @@ public class BatchTest extends Common {
       differentParameterType(con, false);
     }
     try (Connection con = createCon("&useServerPrepStmts&useBulkStmts&useBulkStmtsForInserts")) {
-      differentParameterType(con, isMariaDBServer() && !isXpand());
+      differentParameterType(con, expectUnknown);
     }
     try (Connection con =
         createCon(
             "&useServerPrepStmts&useBulkStmts&useBulkStmtsForInserts&allowLocalInfile=false")) {
-      differentParameterType(con, isMariaDBServer() && !isXpand());
+      differentParameterType(con, expectUnknown);
     }
     try (Connection con =
         createCon("&useServerPrepStmts&useBulkStmtsForInserts&allowLocalInfile=false")) {
@@ -457,13 +462,8 @@ public class BatchTest extends Common {
       prep.addBatch();
       int[] res = prep.executeBatch();
       assertEquals(2, res.length);
-      if (expectSuccessUnknown) {
-        assertEquals(Statement.SUCCESS_NO_INFO, res[0]);
-        assertEquals(Statement.SUCCESS_NO_INFO, res[1]);
-      } else {
-        assertEquals(1, res[0]);
-        assertEquals(2, res[1]);
-      }
+      assertEquals(1, res[0]);
+      assertEquals(2, res[1]);
     }
     rs = stmt.executeQuery("SELECT * FROM BatchTest");
     assertTrue(rs.next());
@@ -656,6 +656,38 @@ public class BatchTest extends Common {
     }
   }
 
+  @Test
+  public void bigParameterFlushTest() throws SQLException {
+    int maxAllowedPacket = getMaxAllowedPacket();
+    Assumptions.assumeTrue(maxAllowedPacket > 22 * 1024 * 1024);
+    String insertStatement =
+        "INSERT INTO batchParamTest (sn_key, sn_name, sn_description, sn_object) VALUES (?, ?, ?,"
+            + " ?)";
+    try (PreparedStatement prep = sharedConn.prepareStatement(insertStatement)) {
+      prep.setInt(1, 1000);
+      prep.setString(2, "name1");
+      prep.setString(3, "desc1");
+      prep.setBytes(4, new byte[334004]);
+      prep.addBatch();
+
+      prep.setInt(1, 1001);
+      prep.setString(2, "name2");
+      prep.setString(3, "desc2");
+      prep.setBytes(4, new byte[21963743]);
+      prep.addBatch();
+
+      prep.executeBatch();
+      prep.clearBatch();
+      sharedConn.commit();
+    }
+    Statement stmt = sharedConn.createStatement();
+    ResultSet rs = stmt.executeQuery("SELECT * FROM batchParamTest");
+    assertTrue(rs.next());
+    assertEquals(334004, rs.getBytes(4).length);
+    assertTrue(rs.next());
+    assertEquals(21963743, rs.getBytes(4).length);
+  }
+
   @Test
   public void ensureCalendarSync() throws SQLException {
     Assumptions.assumeTrue(isMariaDBServer() && !isXpand());
@@ -725,36 +757,4 @@ public class BatchTest extends Common {
       return "TimestampCal{" + "val=" + val + ", id=" + id + '}';
     }
   }
-
-
-  @Test
-  public void batchWithoutParameter() throws SQLException {
-    try (Connection con = createCon("&useServerPrepStmts=false&useBulkStmts=true")) {
-      batchWithoutParameter(con);
-    }
-    try (Connection con = createCon("&useServerPrepStmts=true&useBulkStmts=true")) {
-      batchWithoutParameter(con);
-    }
-  }
-
-  private void batchWithoutParameter(Connection con) throws SQLException {
-    Assumptions.assumeTrue(isMariaDBServer());
-    Statement stmt = con.createStatement();
-    stmt.execute("DROP TABLE IF EXISTS batchWithoutParameter");
-    stmt.setFetchSize(3);
-    stmt.execute("CREATE TABLE batchWithoutParameter(val varchar(10))");
-    try (PreparedStatement prep =
-                 con.prepareStatement("INSERT INTO batchWithoutParameter VALUES ('')")) {
-      prep.addBatch();
-      prep.addBatch();
-      prep.addBatch();
-      prep.addBatch();
-      prep.executeBatch();
-
-      ResultSet rs = stmt.executeQuery("SELECT count(*) FROM batchWithoutParameter");
-      rs.next();
-      assertEquals(rs.getInt(1), 4);
-    }
-  }
-
 }
