@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2024 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration;
 
 import static org.junit.jupiter.api.Assertions.*;
@@ -8,6 +8,7 @@ import static org.junit.jupiter.api.Assertions.*;
 import java.lang.management.ManagementFactory;
 import java.sql.*;
 import java.util.HashSet;
+import java.util.Locale;
 import java.util.Set;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.ThreadPoolExecutor;
@@ -608,7 +609,7 @@ public class PoolDataSourceTest extends Common {
               stmt.execute("SELECT 1");
 
             } catch (SQLException e) {
-              e.printStackTrace();
+              // e.printStackTrace();
             }
           });
     }
@@ -658,7 +659,10 @@ public class PoolDataSourceTest extends Common {
         // ensure more time for windows
         assertTrue(
             (System.currentTimeMillis() - start) >= 500
-                && (System.currentTimeMillis() - start) < 850,
+                && (System.currentTimeMillis() - start)
+                    < (System.getProperty("os.name").toLowerCase(Locale.ROOT).contains("win")
+                        ? 1050
+                        : 800),
             "timeout does not correspond to option. Elapsed time:"
                 + (System.currentTimeMillis() - start));
         assertTrue(
@@ -750,4 +754,26 @@ public class PoolDataSourceTest extends Common {
     new MariaDbPoolDataSource(mDefUrl + "&maxPoolSize=1&poolName=myPool");
     Pools.close();
   }
+
+  @Test
+  public void ensureConnectionClose() throws Exception {
+    MariaDbPoolDataSource datasource = new MariaDbPoolDataSource(mDefUrl);
+
+    Connection c = datasource.getConnection();
+    assertFalse(c.isClosed());
+    c.close();
+    assertFalse(c.isClosed());
+
+    PooledConnection pc = datasource.getPooledConnection();
+    assertFalse(pc.getConnection().isClosed());
+    pc.getConnection().close();
+    assertFalse(pc.getConnection().isClosed());
+    pc.close();
+
+    XAConnection xac = datasource.getXAConnection();
+    assertFalse(xac.getConnection().isClosed());
+    xac.getConnection().close();
+    assertFalse(xac.getConnection().isClosed());
+    xac.close();
+  }
 }
