@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2021 MariaDB Corporation Ab
-
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration.codec;
 
 import static org.junit.jupiter.api.Assertions.*;
@@ -36,8 +35,8 @@ public class TinyIntCodecTest extends CommonCodecTest {
     stmt.execute(
         "CREATE TABLE TinyIntCodec2 (id int not null primary key auto_increment, t1 TINYINT)");
     stmt.execute(
-        "CREATE TABLE TinyIntCodecUnsigned (t1 TINYINT UNSIGNED, t2 TINYINT UNSIGNED, t3 TINYINT UNSIGNED, t4 TINYINT "
-            + "UNSIGNED)");
+        "CREATE TABLE TinyIntCodecUnsigned (t1 TINYINT UNSIGNED, t2 TINYINT UNSIGNED, t3 TINYINT"
+            + " UNSIGNED, t4 TINYINT UNSIGNED)");
     stmt.execute("INSERT INTO TinyIntCodec VALUES (0, 1, -1, null)");
     stmt.execute("INSERT INTO TinyIntCodecUnsigned VALUES (0, 1, 255, null)");
     stmt.execute("FLUSH TABLES");
@@ -874,11 +873,11 @@ public class TinyIntCodecTest extends CommonCodecTest {
 
   public void getArray(ResultSet rs) {
     Common.assertThrowsContains(
-        SQLException.class, () -> rs.getArray(1), "Method ResultSet.getArray not supported");
+        SQLException.class, () -> rs.getArray(1), "Data type TINYINT cannot be decoded as float[]");
     Common.assertThrowsContains(
         SQLException.class,
         () -> rs.getArray("t1alias"),
-        "Method ResultSet.getArray not supported");
+        "Data type TINYINT cannot be decoded as float[]");
   }
 
   @Test
@@ -930,7 +929,7 @@ public class TinyIntCodecTest extends CommonCodecTest {
     assertEquals("t1", meta.getColumnName(1));
     assertEquals(Types.TINYINT, meta.getColumnType(1));
     assertEquals(4, meta.getColumnCount());
-    assertEquals(4, meta.getPrecision(1));
+    assertEquals(3, meta.getPrecision(1));
     assertEquals(0, meta.getScale(1));
     assertEquals("", meta.getSchemaName(1));
     assertEquals(4, meta.getColumnDisplaySize(1));
@@ -944,6 +943,7 @@ public class TinyIntCodecTest extends CommonCodecTest {
     assertEquals("t1", meta.getColumnName(1));
     assertEquals(Types.SMALLINT, meta.getColumnType(1));
     assertEquals(4, meta.getColumnCount());
+    assertEquals(3, meta.getPrecision(1));
     assertEquals(0, meta.getScale(1));
     assertEquals("", meta.getSchemaName(1));
     // https://jira.mariadb.org/browse/XPT-276
@@ -1027,7 +1027,7 @@ public class TinyIntCodecTest extends CommonCodecTest {
 
     assertTrue(rs.next());
     assertEquals(2, rs.getByte(2));
-    rs.updateObject(2, (Byte) null);
+    rs.updateObject(2, null);
     rs.updateRow();
     assertEquals(0, rs.getByte(2));
     assertTrue(rs.wasNull());
